@@ -27,18 +27,9 @@ To use this plugin add the following to your theme:
 
 =cut
 
-=head1 AUTHOR
+=head1 METHODS
 
-Steve Kemp <steve@steve.org.uk>
-
-=cut
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2014 Steve Kemp <steve@steve.org.uk>.
-
-This library is free software. You can modify and or distribute it under
-the same terms as Perl itself.
+Now follows documentation on the available methods.
 
 =cut
 
@@ -49,12 +40,18 @@ use strict;
 use warnings;
 
 
-=begin doc
 
-This is a sneaky hook that builds the data-structure, and makes it
-globally available.
+=head2 on_initiate
 
-=end doc
+The C<on_initiate> method is automatically invoked just before any
+C<on_generate> methods which might be present.
+
+This method updates the global variables, which are made available to
+all loaded templates, to define a C<recent_tags> variable containing the
+recently used tag-names.
+
+The number of tags included in that list will default to 10, but can
+be changed via the C<recent-tag-count> setting in the configuration file.
 
 =cut
 
@@ -96,7 +93,7 @@ sub on_initiate
 }
 
 
-=begin doc
+=head2 _order
 
 This plugin must be called "early".
 
@@ -104,8 +101,6 @@ This means we're called prior to any of the page-generation plugins, such
 that any page-templates which make use of the data-structure we've created
 are called after that structure is setup.
 
-=end doc
-
 =cut
 
 sub _order
