@@ -5,30 +5,23 @@ Chronicle::Plugin::Textile - Support textile-formatted input.
 
 =head1 DESCRIPTION
 
-The module allows you to write your input blog-entries in the textile format.
+The module allows you to write your input blog-entries in the
+Textile format.
 
-Add the "C<format: textile>" header to your entries and they
+Add the C<format: textile> header to your entries and they
 will be automatically converted as part of the import process.
 
-B<NOTE> If you enable/disable this plugin you will need to regenerate
+B<NOTE>  If you enable/disable this plugin you will need to regenerate
 your SQLite database, because the conversion happens at import-time.
 
 =cut
 
-=head1 AUTHOR
+=head1 METHODS
 
-Steve Kemp <steve@steve.org.uk>
+Now follows documentation on the available methods.
 
 =cut
 
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2014 Steve Kemp <steve@steve.org.uk>.
-
-This library is free software. You can modify and or distribute it under
-the same terms as Perl itself.
-
-=cut
 
 
 package Chronicle::Plugin::Textile;
@@ -36,15 +29,18 @@ package Chronicle::Plugin::Textile;
 use strict;
 use warnings;
 
+=head2 on_insert
 
-=begin doc
+The C<on_insert> method is automatically invoked when a new blog post
+must be inserted into the SQLite database, that might be because a post
+is new, or because it has been updated.
 
-This method will be called whenever a new blog-post is imported to the database.
+The method is designed to return an updated blog-post structure,
+after performing any massaging required.  If the method returns undef
+then the post is not inserted.
 
-We look for a format header, and if it is found we'll update the content
-if that header has a value of 'textile'.
-
-=end doc
+If the new entry has a C<format:> header which contains the value C<markdown>
+we invoke the L<Text::Textile> module to perform the HTML conversion.
 
 =cut
 
@@ -52,11 +48,13 @@ sub on_insert
 {
     my ( $self, %args ) = (@_);
 
-    my $dbh    = $args{ 'dbh' };
-    my $config = $args{ 'config' };
+    #
+    #  The post data and input-format
+    #
     my $data   = $args{ 'data' };
+    my $format = $data->{ 'format' };
 
-    if ( $data->{ 'format' } && lc( $data->{ 'format' } ) eq "textile" )
+    if ( $format && ( $format =~ /^textile$/i ) )
     {
         my $test = "use Text::Textile;";
 
